/*
	File: CEG_smoke.sqf
	Version: 0.9.6
	Author: Loyalguard

	Description:
	A script to emit smoke from the power plant smokestacks in Elektrozavodsk and Chernogorsk

	Parameters:
	_this select 0: The CEG object co-located with game logic that emits smoke (string).
	
	Execution:
	Executed from CEG_common.sqf on all machines except MP dedicated servers (since there is no one there to see the smoke).  Multiple instances of this script will be running concurrently, one for every logic that might emit smoke in the simulation.
*/

if (!isNil "CEG_DEBUG") then {_debug = ["CEG_smoke.sqf: Thread started for:", (_this select 0)] call LGD_fnc_debugMessage;}; //DEBUG 

// Scope //
private ["_obj", "_bool", "_logic", "_source"];

// Parameter(s) //
_obj = (_this select 0);

// Determine which smokestack to emit smoke (Elektrozavodsk "P_Elek" or Chernogorsk "P_Cher").

switch (_obj) do
{
	case "S_Elek":
	{
			waitUntil {(CEG_on_S_Elek)};
			_smokeElek = "#particlesource" createVehicleLocal getPos CEG_logic_S_Elek;
			_smokeElek setParticleCircle [0, [0, 0, 0]];
			_smokeElek setParticleRandom [0, [0.25, 0.25, 0], [0.175, 0.175, 0], 0, 0.25, [0, 0, 0, 0.1], 0, 0];
			_smokeElek setParticleParams [["\Ca\Data\Cl_basic.p3d", 1, 0, 1], "", "Billboard", 1, 12.5, [0, 0, 0], [0, 0, 0.75], 0, 10, 7.9, 0.075, [1.2, 2, 4], [[0.1, 0.1, 0.1, 1], [0.25, 0.25, 0.25, 0.5], [0.5, 0.5, 0.5, 0]], [0.08], 1, 0, "", "", CEG_logic_S_Elek];
			_smokeElek setDropInterval 0.05;

			waitUntil {!(CEG_on_S_Elek)};
			deleteVehicle _smokeElek;
		};
				
	case "S_Cher":
	{
		while {true} do
		{
			waitUntil {(CEG_on_S_Cher)};
			_smokeCher = "#particlesource" createVehicleLocal getPos CEG_logic_S_Cher;
			_smokeCher setParticleCircle [0, [0, 0, 0]];
			_smokeCher setParticleRandom [0, [0.25, 0.25, 0], [0.175, 0.175, 0], 0, 0.25, [0, 0, 0, 0.1], 0, 0];
			_smokeCher setParticleParams [["\Ca\Data\Cl_basic.p3d", 1, 0, 1], "", "Billboard", 1, 12.5, [0, 0, 0], [0, 0, 0.75], 0, 10, 7.9, 0.075, [1.2, 2, 4], [[0.1, 0.1, 0.1, 1], [0.25, 0.25, 0.25, 0.5], [0.5, 0.5, 0.5, 0]], [0.08], 1, 0, "", "", CEG_logic_S_Cher];
			_smokeCher setDropInterval 0.05;

			waitUntil {!(CEG_on_S_Cher)};
			deleteVehicle _smokeCher;
			};						
	};
};


